@@ -8,6 +8,10 @@ class EnvDBResource(object):
     def __init__(self, db_name="nodes"):
         self.sql = SqlConnection(db_name=db_name)
 
+    def __del__(self):
+        print("__del__EnvDBResource")
+        del self.sql
+
     def _get_all_nodes(self):
         sea_string = "SELECT * FROM node"
         result = self.sql.execute_sql_command(sea_string)
@@ -103,8 +107,9 @@ class EnvDBResource(object):
         self.sql.cursor.execute(cmd)
         self.sql.conn.commit()
 
-
-if __name__ == '__main__':
-    DB = EnvDBResource()
-    aa = DB.get_node_usage_rate("172.29.131.117")
-    pass
\ No newline at end of file
+#
+# if __name__ == '__main__':
+#     DB = EnvDBResource()
+#     aa = DB.get_node_usage_rate("172.29.131.117")
+#     print(aa)
+#     del aa
