@@ -5,7 +5,7 @@ from resources.models.helper import rest_get_call
 from resources.models.helper import rest_post_json_call
 from resources.models.helper import rest_delete_call
 from resources.models.helper import State
-from resources.models.database import SqlConnection
+from resources.test_db_resource import TestDBResource
 
 
 class TestResource(object):
@@ -42,15 +42,16 @@ class TestResource(object):
         url_ = "http://{0}:{1}/test/results/{2}".format(self.host, self.port, key)
         result = rest_get_call(url_, self.session, self.time_out)
         if result["resource"]["state"] in [State.ERROR_TIMEOUT, State.ERROR_CONNECTION, State.ERROR_NOT_FOUND]:
-            sql_connection = SqlConnection()
+            sql_connection = TestDBResource()
             ret = sql_connection.get_result(key)
             if ret:
                 result["resource"] = {"msg": "Get result from database\n{}".format(ret[7]), "state": ret[4]}
         return result["resource"]
 
-    def get_result_from_db(self, key):
+    @staticmethod
+    def get_result_from_db(key):
         result = dict()
-        sql_connection = SqlConnection()
+        sql_connection = TestDBResource()
         ret = sql_connection.get_result(key)
         if ret:
             result["resource"] = {"msg": ret[7], "state": ret[4]}
