@@ -9,6 +9,7 @@ from resources.operation_resource import OperationResource
 from resources.state_resource import StateResource
 from resources.remote_resource import RemoteResource
 from resources.benchmark_resource import BenchmarkResource
+from resources.oakgate_resource import OakgateResource
 
 
 class RestClient(object):
@@ -20,3 +21,9 @@ class RestClient(object):
         self.state = StateResource(host, port, __session, time_out=time_out)
         self.remote = RemoteResource(host, port)
         self.benchmark = BenchmarkResource(host, port, __session, time_out)
+        self.oakgate = OakgateResource(host, port, __session, time_out)
+
+#
+# R = RestClient("172.29.130.138")
+# a = R.oakgate.get_oakgate_device_list()
+# pass
